core

package
v0.0.0-...-800ad12 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Sep 19, 2025 License: Apache-2.0 Imports: 25 Imported by: 0

Documentation

Index

Constants

const ConsensusVersion = 1

ConsensusVersion defines the current module consensus version.

Variables

This section is empty.

Functions

This section is empty.

Types

type AppModule

type AppModule struct {
	// contains filtered or unexported fields
}

func NewAppModule

func NewAppModule(cdc codec.Codec, keeper *keeper2.Keeper) AppModule

NewAppModule creates a new AppModule object

func (AppModule) AutoCLIOptions

func (am AppModule) AutoCLIOptions() *autocliv1.ModuleOptions

func (AppModule) ConsensusVersion

func (AppModule) ConsensusVersion() uint64

ConsensusVersion implements AppModule/ConsensusVersion.

func (AppModule) DefaultGenesis

func (AppModule) DefaultGenesis(cdc codec.JSONCodec) json.RawMessage

DefaultGenesis returns default genesis state as raw bytes for the module.

func (AppModule) ExportGenesis

func (am AppModule) ExportGenesis(ctx sdk.Context, cdc codec.JSONCodec) json.RawMessage

ExportGenesis returns the exported genesis

func (AppModule) GetQueryCmd

func (am AppModule) GetQueryCmd() *cobra.Command

GetQueryCmd implements AppModuleBasic interface

func (AppModule) GetTxCmd

func (am AppModule) GetTxCmd() *cobra.Command

GetTxCmd implements AppModuleBasic interface

func (AppModule) InitGenesis

func (am AppModule) InitGenesis(ctx sdk.Context, cdc codec.JSONCodec, data json.RawMessage)

InitGenesis performs genesis initialization for the core module. It returns no validator updates.

func (AppModule) IsAppModule

func (am AppModule) IsAppModule()

IsAppModule implements the appmodule.AppModule interface.

func (AppModule) IsOnePerModuleType

func (am AppModule) IsOnePerModuleType()

IsOnePerModuleType implements the depinject.OnePerModuleType interface.

func (AppModule) Name

func (AppModule) Name() string

Name returns the mailbox module's name.

func (AppModule) RegisterGRPCGatewayRoutes

func (AppModule) RegisterGRPCGatewayRoutes(clientCtx client.Context, mux *gwruntime.ServeMux)

RegisterGRPCGatewayRoutes registers the gRPC Gateway routes for the mailbox module.

func (AppModule) RegisterInterfaces

func (AppModule) RegisterInterfaces(registry codectypes.InterfaceRegistry)

RegisterInterfaces registers interfaces and implementations of the mailbox module.

func (AppModule) RegisterLegacyAminoCodec

func (AppModule) RegisterLegacyAminoCodec(cdc *codec.LegacyAmino)

RegisterLegacyAminoCodec registers the mailbox module's types on the LegacyAmino codec. New modules do not need to support Amino.

func (AppModule) RegisterServices

func (am AppModule) RegisterServices(cfg module.Configurator)

RegisterServices registers a gRPC query service to respond to the module-specific gRPC queries.

func (AppModule) ValidateGenesis

func (AppModule) ValidateGenesis(cdc codec.JSONCodec, _ client.TxEncodingConfig, bz json.RawMessage) error

ValidateGenesis performs genesis state validation for the core module.

type ModuleInputs

type ModuleInputs struct {
	depinject.In

	Cdc          codec.Codec
	StoreService store.KVStoreService
	AddressCodec address.Codec

	Config *modulev1.Module

	BankKeeper types.BankKeeper
}

type ModuleOutputs

type ModuleOutputs struct {
	depinject.Out

	Module appmodule.AppModule
	Keeper *keeper.Keeper
}

func ProvideModule

func ProvideModule(in ModuleInputs) ModuleOutputs

Directories

Path Synopsis
Package interchain_security provides the core interchain security module for Hyperlane.
Package interchain_security provides the core interchain security module for Hyperlane.
keeper
Package keeper provides the core keeper implementation for the interchain security module.
Package keeper provides the core keeper implementation for the interchain security module.
types
Package types defines the core data structures and interfaces for the interchain security module.
Package types defines the core data structures and interfaces for the interchain security module.
Package post_dispatch provides the post-dispatch hooks module for Hyperlane.
Package post_dispatch provides the post-dispatch hooks module for Hyperlane.
keeper
Package keeper implements the Interchain Gas Paymaster (IGP) hook functionality for the Hyperlane post-dispatch module.
Package keeper implements the Interchain Gas Paymaster (IGP) hook functionality for the Hyperlane post-dispatch module.
types
Package types defines the core data structures and interfaces for the post dispatch module.
Package types defines the core data structures and interfaces for the post dispatch module.
client
cli
Package keeper implements the core business logic for Hyperlane message processing.
Package keeper implements the core business logic for Hyperlane message processing.
Package types defines the core data structures and interfaces for the hyperlane core module.
Package types defines the core data structures and interfaces for the hyperlane core module.

Jump to